@@ -23,7 +23,7 @@
 #' @examples
 #' interpret_stage <- bid_interpret(
 #'   central_question = "How can we improve selection efficiency?",
-#'   data_story = list(
+#'   data_story = new_data_story(
 #'     hook = "Too many options",
 #'     context = "Excessive choices",
 #'     tension = "User frustration",
@@ -126,9 +126,9 @@ bid_anticipate <- function(
         ))
         bias_mitigations <- NULL
       } else {
-        empty_values <- sapply(bias_mitigations, function(x) {
+        empty_values <- vapply(bias_mitigations, function(x) {
           is.null(x) || is.na(x) || (is.character(x) && nchar(trimws(x)) == 0)
-        })
+        }, logical(1))
 
         if (any(empty_values)) {
           cli::cli_warn(c(
@@ -275,74 +275,7 @@ bid_anticipate <- function(
       }
     }
 
-    # apply layout-specific bias mitigations when layout information is
-    # available
-    # DEPRECATED in 0.3.1:
-    # TODO: Will be removed in 0.4.0 in favor of concept-only approach
-    if (!is.na(layout)) {
-      # issue deprecation warning once per session (skip in tests to reduce
-      # noise). use package namespace instead of global environment for CRAN
-      # compliance
-      pkg_env <- asNamespace("bidux")
-      if (
-        !exists(".bid_layout_bias_warned", envir = pkg_env) &&
-          !identical(Sys.getenv("TESTTHAT"), "true")
-      ) {
-        warning(
-          paste(
-            "Layout-specific bias mitigations are deprecated",
-            "and will be removed in bidux 0.4.0. "
-          ),
-          "Consider using concept-based bias mitigations instead.",
-          call. = FALSE
-        )
-        try(
-          assign(".bid_layout_bias_warned", TRUE, envir = pkg_env),
-          silent = TRUE
-        )
-      }
-
-      layout_bias_map <- list(
-        "dual_process" = c(
-          "framing" = paste(
-            "Toggle between high-level summary",
-            "and detailed analysis views"
-          )
-        ),
-        "grid" = c(
-          "anchoring" = paste(
-            "Provide multiple reference points across grid cells",
-            "to avoid single point anchoring"
-          )
-        ),
-        "card" = c(
-          "beautiful-is-good stereotype" = paste(
-            "Ensure card aesthetic appeal doesn't overshadow",
-            "content quality"
-          )
-        ),
-        "tabs" = c(
-          "availability bias" = paste(
-            "Make important information available in the default tab",
-            "to prevent availability bias"
-          )
-        ),
-        "breathable" = c(
-          "cognitive load" = paste(
-            "Use generous whitespace to reduce cognitive load",
-            "and improve focus"
-          )
-        )
-      )
-
-      if (!is.na(layout) && layout %in% names(layout_bias_map)) {
-        for (bias_name in names(layout_bias_map[[layout]])) {
-          suggested_biases[[bias_name]] <- layout_bias_map[[layout]][[
-            bias_name
-          ]]
-        }
-      }
-    } else if (previous_stage$stage[1] == "Interpret") {
+    if (previous_stage$stage[1] == "Interpret") {
       story_elements <- list()
       for (field in c("central_question", "hook", "tension", "resolution")) {
         if (
@@ -354,7 +287,7 @@ bid_anticipate <- function(
         }
       }
 
-      valid_elements <- !sapply(story_elements, is.na)
+      valid_elements <- !vapply(story_elements, is.na, logical(1))
       if (any(valid_elements)) {
         combined_text <- tolower(paste(
           unlist(story_elements[valid_elements]),
@@ -390,7 +323,7 @@ bid_anticipate <- function(
 
         for (bias_name in names(bias_keywords)) {
           keywords <- bias_keywords[[bias_name]]
-          if (any(sapply(keywords, function(k) grepl(k, combined_text)))) {
+          if (any(vapply(keywords, function(k) grepl(k, combined_text), logical(1)))) {
             tension_field <- if (!is.na(story_elements$tension)) {
               "tension"
             } else {
@@ -446,11 +379,9 @@ bid_anticipate <- function(
 
     bias_mitigations <- suggested_biases
 
-    message(
-      paste0(
-        "Automatically suggested bias mitigations: ",
-        paste(names(bias_mitigations), collapse = ", ")
-      )
+    bid_alert_info(
+      "Automatically suggested bias mitigations: {paste(names(bias_mitigations), collapse = ', ')}.",
+      quiet = quiet
     )
   }
 
@@ -464,7 +395,7 @@ bid_anticipate <- function(
     accessibility_advice <- get_accessibility_advice(layout_context)
     bias_mitigations$accessibility <- accessibility_advice
 
-    message("Added accessibility mitigation based on layout context")
+    bid_alert_info("Added accessibility mitigation based on layout context.", quiet = quiet)
   }
 
   bias_suggestions <- character(0)
