@@ -1,3 +1,54 @@
+# TODO [0.4.0 - Accessibility Auditing Integration]: Add accessibility audit to validation stage
+#
+# INTEGRATION TASKS:
+#
+# [ ] 1. Add new parameters to bid_validate():
+#     - include_accessibility_audit = TRUE (default: run audit during validation)
+#     - accessibility_level = c("AA", "A", "AAA") (default: "AA")
+#     - html_output = NULL (optional: for deeper HTML-based checks)
+#
+# [ ] 2. Update function body:
+#     - After existing validation logic, check if include_accessibility_audit = TRUE
+#     - If TRUE, call bid_audit_accessibility(previous_stage, wcag_level = accessibility_level, html_output = html_output, quiet = quiet)
+#     - Store audit results in validation output
+#     - Generate summary message: "Accessibility audit: Score X/100 (Y critical, Z high violations)"
+#
+# [ ] 3. Integrate audit results into validation suggestions:
+#     - If accessibility score < 80, add high-priority validation suggestion
+#     - If critical violations exist, add them to next_steps
+#     - Link violations back to specific components from Structure stage
+#
+# [ ] 4. Update validation output tibble:
+#     - Add accessibility_audit column containing nested audit results tibble
+#     - Add accessibility_score column with overall score (0-100)
+#     - Add accessibility_status column: "Pass" (>=90), "Warning" (80-89), "Fail" (<80)
+#
+# [ ] 5. Update @param documentation:
+#     - Document new include_accessibility_audit parameter
+#     - Document new accessibility_level parameter
+#     - Document new html_output parameter
+#
+# [ ] 6. Add to @examples:
+#     ```r
+#     # Validation with accessibility audit
+#     validate_result <- bid_validate(
+#       previous_stage = structure_result,
+#       include_accessibility_audit = TRUE,
+#       accessibility_level = "AA"
+#     )
+#
+#     # View accessibility audit results
+#     validate_result$accessibility_audit
+#     ```
+#
+# [ ] 7. Update tests in tests/testthat/test-bid_validate.R:
+#     - Test with include_accessibility_audit = TRUE
+#     - Test with different accessibility_level values
+#     - Test that audit results are properly attached
+#     - Test integration with other validation features
+#
+# See R/bid_audit_accessibility.R for complete accessibility audit implementation details
+
 #' Document User Validation Stage in BID Framework
 #'
 #' @description
@@ -31,7 +82,7 @@
 #' @examples
 #' validate_result <- bid_interpret(
 #'   central_question = "How can we improve delivery efficiency?",
-#'   data_story = list(
+#'   data_story = new_data_story(
 #'     hook = "Too many delays",
 #'     context = "Excessive shipments",
 #'     tension = "User frustration",
@@ -76,6 +127,17 @@ bid_validate <- function(
   validate_logical_param(include_telemetry, "include_telemetry")
   validate_logical_param(include_empower_tools, "include_empower_tools")
 
+  # validate against NA values for nullable string parameters
+  if (!is.null(summary_panel) && is.atomic(summary_panel) && any(is.na(summary_panel))) {
+    cli::cli_abort("Parameter {.arg summary_panel} must not be {.val NA}. Provide a valid string or leave as NULL.")
+  }
+  if (!is.null(collaboration) && is.atomic(collaboration) && any(is.na(collaboration))) {
+    cli::cli_abort("Parameter {.arg collaboration} must not be {.val NA}. Provide a valid string or leave as NULL.")
+  }
+  if (!is.null(next_steps) && is.atomic(next_steps) && any(is.na(next_steps))) {
+    cli::cli_abort("Parameter {.arg next_steps} must not be {.val NA}. Provide a valid string or leave as NULL.")
+  }
+
   if (is.null(summary_panel)) {
     summary_panel <- generate_summary_panel_suggestion(previous_stage)
     bid_alert_info(
@@ -240,27 +302,31 @@ generate_collaboration_suggestion <- function(
 
   if (!is.na(audience) && nchar(trimws(audience)) > 0) {
     audience_lower <- tolower(audience)
+    audience_type <- classify_audience(audience)
 
     empowerment_suffix <- if (include_empower_tools) {
-      if (grepl("executive|leadership|manager", audience_lower)) {
-        " with executive empowerment tools like annotated insights and decision history"
-      } else if (grepl("analyst|technical|data", audience_lower)) {
-        " with analyst empowerment features like exploratory chat and methodology explanations"
-      } else if (grepl("team|group|multiple", audience_lower)) {
-        " with team empowerment via shared workspaces and collaborative insights"
-      } else {
-        " with user empowerment through guided explanations and contextual help"
-      }
+      switch(audience_type,
+        "executive"  = " with executive empowerment tools like annotated insights and decision history",
+        "analyst"    = " with analyst empowerment features like exploratory chat and methodology explanations",
+        # fall back to inline check for team/group which classify_audience doesn't distinguish
+        {
+          if (grepl("team|group|multiple", audience_lower)) {
+            " with team empowerment via shared workspaces and collaborative insights"
+          } else {
+            " with user empowerment through guided explanations and contextual help"
+          }
+        }
+      )
     } else {
       ""
     }
 
-    if (grepl("executive|leadership|manager", audience_lower)) {
+    if (audience_type == "executive") {
       return(paste0(
         "Executive-focused collaboration with summary sharing and decision tracking",
         empowerment_suffix
       ))
-    } else if (grepl("analyst|technical|data", audience_lower)) {
+    } else if (audience_type == "analyst") {
       return(paste0(
         "Advanced collaboration tools including data export, annotation, and methodology sharing",
         empowerment_suffix
