@@ -1,9 +1,21 @@
+#' Create a telemetry notice from problem and evidence
+#' @param central_question The central question for the interpret stage
+#' @param problem Problem description string
+#' @param evidence Evidence description string
+#' @return bid_stage object in the Notice stage
+#' @keywords internal
+create_telemetry_notice <- function(central_question, problem, evidence) {
+  interpret <- bid_interpret(central_question = central_question)
+  bid_notice(previous_stage = interpret, problem = problem, evidence = evidence)
+}
+
 #' Create notice stage for unused input
 #' @param input_info List with input usage information
 #' @param total_sessions Total number of sessions
+#' @param events Optional full events data frame for performance context
 #' @return bid_stage object
 #' @keywords internal
-create_unused_input_notice <- function(input_info, total_sessions) {
+create_unused_input_notice <- function(input_info, total_sessions, events = NULL) {
   problem <- sprintf(
     "Users are not interacting with the '%s' input control",
     input_info$input_id
@@ -25,27 +37,30 @@ create_unused_input_notice <- function(input_info, total_sessions) {
     )
   }
 
-  # create interpret stage first, then notice stage with auto-suggested theory
-  interpret <- bid_interpret(
-    central_question = "How can we improve user interaction with unused inputs?"
-  )
+  # add performance context if available (for used inputs with timing data)
+  if (!is.null(events) && input_info$sessions_used > 0) {
+    event_filter <- events$event_type == "input" &
+      !is.na(events$input_id) &
+      events$input_id == input_info$input_id
+    evidence <- add_performance_context(evidence, events, event_filter)
+  }
 
-  notice <- bid_notice(
-    previous_stage = interpret,
+  # create interpret then notice stages via shared factory
+  create_telemetry_notice(
+    central_question = "How can we improve user interaction with unused inputs?",
     problem = problem,
     evidence = evidence
   )
-
-  return(notice)
 }
 
 #' Create notice stage for delayed interactions
 #' @param delay_info List with delay statistics
 #' @param total_sessions Total number of sessions
 #' @param threshold Threshold used for analysis
+#' @param events Optional full events data frame for performance context
 #' @return bid_stage object
 #' @keywords internal
-create_delay_notice <- function(delay_info, total_sessions, threshold) {
+create_delay_notice <- function(delay_info, total_sessions, threshold, events = NULL) {
   problem <- "Users take a long time before making their first interaction with the dashboard"
 
   evidence_parts <- character(0)
@@ -83,26 +98,27 @@ create_delay_notice <- function(delay_info, total_sessions, threshold) {
 
   evidence <- paste(evidence_parts, collapse = ", and ")
 
-  # create interpret stage first, then notice stage
-  interpret <- bid_interpret(
-    central_question = "How can we reduce user interaction delays?"
-  )
+  # add performance context from login/session_start spans if available
+  if (!is.null(events)) {
+    event_filter <- events$event_type == "login"
+    evidence <- add_performance_context(evidence, events, event_filter)
+  }
 
-  notice <- bid_notice(
-    previous_stage = interpret,
+  # create interpret then notice stages via shared factory
+  create_telemetry_notice(
+    central_question = "How can we reduce user interaction delays?",
     problem = problem,
     evidence = evidence
   )
-
-  return(notice)
 }
 
 #' Create notice stage for error patterns
 #' @param error_info List with error pattern information
 #' @param total_sessions Total number of sessions
+#' @param events Optional full events data frame for performance context
 #' @return bid_stage object
 #' @keywords internal
-create_error_notice <- function(error_info, total_sessions) {
+create_error_notice <- function(error_info, total_sessions, events = NULL) {
   problem <- "Users encounter errors when using the dashboard"
 
   evidence_parts <- sprintf(
@@ -126,26 +142,34 @@ create_error_notice <- function(error_info, total_sessions) {
     )
   }
 
-  # create interpret stage first, then notice stage
-  interpret <- bid_interpret(
-    central_question = "How can we reduce user errors and confusion?"
-  )
+  # add performance context from error events if available
+  if (!is.null(events)) {
+    event_filter <- events$event_type == "error" &
+      !is.na(events$error_message) &
+      events$error_message == error_info$error_message
+    if (!is.null(error_info$output_id)) {
+      event_filter <- event_filter &
+        !is.na(events$output_id) &
+        events$output_id == error_info$output_id
+    }
+    evidence_parts <- add_performance_context(evidence_parts, events, event_filter)
+  }
 
-  notice <- bid_notice(
-    previous_stage = interpret,
+  # create interpret then notice stages via shared factory
+  create_telemetry_notice(
+    central_question = "How can we reduce user errors and confusion?",
     problem = problem,
     evidence = evidence_parts
   )
-
-  return(notice)
 }
 
 #' Create notice stage for navigation issues
 #' @param nav_info List with navigation pattern information
 #' @param total_sessions Total number of sessions
+#' @param events Optional full events data frame for performance context
 #' @return bid_stage object
 #' @keywords internal
-create_navigation_notice <- function(nav_info, total_sessions) {
+create_navigation_notice <- function(nav_info, total_sessions, events = NULL) {
   problem <- sprintf(
     "The '%s' page/tab is rarely visited by users",
     nav_info$page
@@ -168,26 +192,29 @@ create_navigation_notice <- function(nav_info, total_sessions) {
     )
   }
 
-  # create interpret stage first, then notice stage
-  interpret <- bid_interpret(
-    central_question = "How can we improve user navigation flow?"
-  )
+  # add performance context from navigation events if available
+  if (!is.null(events)) {
+    event_filter <- events$event_type == "navigation" &
+      !is.na(events$navigation_id) &
+      events$navigation_id == nav_info$page
+    evidence <- add_performance_context(evidence, events, event_filter)
+  }
 
-  notice <- bid_notice(
-    previous_stage = interpret,
+  # create interpret then notice stages via shared factory
+  create_telemetry_notice(
+    central_question = "How can we improve user navigation flow?",
     problem = problem,
     evidence = evidence
   )
-
-  return(notice)
 }
 
 #' Create notice stage for confusion patterns
 #' @param confusion_info List with confusion pattern information
 #' @param total_sessions Total number of sessions
+#' @param events Optional full events data frame for performance context
 #' @return bid_stage object
 #' @keywords internal
-create_confusion_notice <- function(confusion_info, total_sessions) {
+create_confusion_notice <- function(confusion_info, total_sessions, events = NULL) {
   problem <- sprintf(
     "Users show signs of confusion when interacting with '%s'",
     confusion_info$input_id
@@ -200,18 +227,20 @@ create_confusion_notice <- function(confusion_info, total_sessions) {
     confusion_info$avg_time_window
   )
 
-  # create interpret stage first, then notice stage
-  interpret <- bid_interpret(
-    central_question = "How can we improve user navigation flow?"
-  )
+  # add performance context from rapid input changes if available
+  if (!is.null(events)) {
+    event_filter <- events$event_type == "input" &
+      !is.na(events$input_id) &
+      events$input_id == confusion_info$input_id
+    evidence <- add_performance_context(evidence, events, event_filter)
+  }
 
-  notice <- bid_notice(
-    previous_stage = interpret,
+  # create interpret then notice stages via shared factory
+  create_telemetry_notice(
+    central_question = "How can we improve user navigation flow?",
     problem = problem,
     evidence = evidence
   )
-
-  return(notice)
 }
 
 #' Create tidy issues tibble from notice issues list
@@ -425,16 +454,8 @@ create_confusion_notice <- function(confusion_info, total_sessions) {
     }
   }
 
-  # determine severity based on impact rate
-  severity <- if (impact_rate >= 0.3) {
-    "critical"
-  } else if (impact_rate >= 0.1) {
-    "high"
-  } else if (impact_rate >= 0.05) {
-    "medium"
-  } else {
-    "low"
-  }
+  # delegate severity calculation to shared utility (single source of truth)
+  severity <- calculate_severity(impact_rate)
 
   list(
     severity = severity,
@@ -592,13 +613,23 @@ bid_flags.default <- function(x) {
 #' of identified issues without the legacy list structure. Use this function
 #' for new workflows that don't need backward compatibility.
 #'
+#' **OpenTelemetry Support**: For Shiny >= 1.12.0 applications using native
+#' OpenTelemetry, pass the path to OTLP JSON exports or OTEL-formatted
+#' SQLite databases. Format is auto-detected. See
+#' \code{vignette("otel-integration")} for complete setup guide.
+#'
 #' @inheritParams bid_ingest_telemetry
 #' @return A tibble of class "bid_issues_tbl" with structured issue metadata
 #' @export
 #' @examples
 #' \dontrun{
-#' # Modern workflow
+#' # Works with shiny.telemetry
 #' issues <- bid_telemetry("telemetry.sqlite")
+#'
+#' # Works with Shiny OpenTelemetry (1.12+)
+#' issues <- bid_telemetry("otel_spans.json")
+#'
+#' # Same analysis workflow for both
 #' high_priority <- issues[issues$severity %in% c("critical", "high"), ]
 #'
 #' # Use DBI connection directly
