@@ -3,9 +3,10 @@
 # ==============================================================================
 
 create_test_stage <- function(
-    stage_name = "Notice",
-    problem = "Test problem",
-    evidence = "Test evidence") {
+  stage_name = "Notice",
+  problem = "Test problem",
+  evidence = "Test evidence"
+) {
   tibble::tibble(
     stage = stage_name,
     problem = problem,
@@ -108,15 +109,15 @@ test_that("bid_message respects quiet mode", {
 
   # test with quiet = FALSE
   options(bidux.quiet = FALSE)
-  expect_output(bid_message("Title", "Message 1", "Message 2"), "Title")
-  expect_output(bid_message("Title", "Message 1", "Message 2"), "Message 1")
+  expect_message(bid_message("Title", "Message 1", "Message 2"), "Title")
+  expect_message(bid_message("Title", "Message 1", "Message 2"), "Message 1")
 
   # test with quiet = TRUE
   options(bidux.quiet = TRUE)
   expect_silent(bid_message("Title", "Message 1", "Message 2"))
 
   # test parameter override
-  expect_output(bid_message("Title", "Message", quiet = FALSE), "Title")
+  expect_message(bid_message("Title", "Message", quiet = FALSE), "Title")
   expect_silent(bid_message("Title", "Message", quiet = TRUE))
 
   # test edge cases
@@ -320,13 +321,21 @@ test_that("safe_df_check works correctly", {
 })
 
 test_that("safe_column_access works correctly", {
-  test_df <- data.frame(a = c(1, 2), b = c("x", "y"), c = c(NA, "z"), d = c(NA, NA))
+  test_df <- data.frame(
+    a = c(1, 2),
+    b = c("x", "y"),
+    c = c(NA, "z"),
+    d = c(NA, NA)
+  )
 
   expect_equal(safe_column_access(test_df, "a"), 1)
   expect_equal(safe_column_access(test_df, "b"), "x")
   expect_equal(safe_column_access(test_df, "missing", "default"), "default")
   expect_equal(safe_column_access(NULL, "a", "default"), "default")
-  expect_equal(safe_column_access(test_df, "c", default = "custom"), NA_character_)
+  expect_equal(
+    safe_column_access(test_df, "c", default = "custom"),
+    NA_character_
+  )
   expect_equal(safe_column_access(test_df, "d", "custom"), "custom")
 })
 
@@ -530,16 +539,20 @@ test_that("get_accessibility_advice works correctly", {
   expect_gt(nchar(result_null), 0)
 })
 
-test_that("safe_data_story_access works with legacy plain list", {
-  data_story <- list(
+test_that("safe_data_story_access works with new_data_story format", {
+  data_story <- new_data_story(
     hook = "Test hook",
     context = "Test context",
-    resolution = ""
+    tension = "Test tension",
+    resolution = "Test resolution"
   )
 
   expect_equal(safe_data_story_access(data_story, "hook"), "Test hook")
   expect_equal(safe_data_story_access(data_story, "context"), "Test context")
-  expect_true(is.na(safe_data_story_access(data_story, "resolution"))) # empty
+  expect_equal(
+    safe_data_story_access(data_story, "resolution"),
+    "Test resolution"
+  )
   expect_true(is.na(safe_data_story_access(data_story, "missing")))
   expect_true(is.na(safe_data_story_access(NULL, "hook")))
 })
@@ -556,28 +569,28 @@ test_that("safe_data_story_access works with new flat format", {
   )
 
   expect_equal(safe_data_story_access(data_story_flat, "hook"), "Flat hook")
-  expect_equal(safe_data_story_access(data_story_flat, "context"), "Flat context")
-  expect_equal(safe_data_story_access(data_story_flat, "tension"), "Flat tension")
-  expect_equal(safe_data_story_access(data_story_flat, "resolution"), "Flat resolution")
-  expect_equal(safe_data_story_access(data_story_flat, "audience"), "test audience")
-  expect_equal(safe_data_story_access(data_story_flat, "metrics"), "metric1, metric2")
+  expect_equal(
+    safe_data_story_access(data_story_flat, "context"),
+    "Flat context"
+  )
+  expect_equal(
+    safe_data_story_access(data_story_flat, "tension"),
+    "Flat tension"
+  )
+  expect_equal(
+    safe_data_story_access(data_story_flat, "resolution"),
+    "Flat resolution"
+  )
+  expect_equal(
+    safe_data_story_access(data_story_flat, "audience"),
+    "test audience"
+  )
+  expect_equal(
+    safe_data_story_access(data_story_flat, "metrics"),
+    "metric1, metric2"
+  )
 })
 
-test_that("safe_data_story_access works with old nested format", {
-  # create old nested format data_story with deprecation warning suppression
-  suppressWarnings({
-    data_story_nested <- new_data_story(
-      context = "Nested context",
-      variables = list(hook = "Nested hook", tension = "Nested tension"),
-      relationships = list(resolution = "Nested resolution")
-    )
-  })
-
-  expect_equal(safe_data_story_access(data_story_nested, "context"), "Nested context")
-  expect_equal(safe_data_story_access(data_story_nested, "hook"), "Nested hook")
-  expect_equal(safe_data_story_access(data_story_nested, "tension"), "Nested tension")
-  expect_equal(safe_data_story_access(data_story_nested, "resolution"), "Nested resolution")
-})
 
 # ==============================================================================
 # SUGGESTION SYSTEM
@@ -588,7 +601,12 @@ test_that("generate_stage_suggestions works correctly", {
   if (exists("apply_suggestion_rules") && exists("get_fallback_suggestion")) {
     interpret_context <- list(
       central_question = "How to improve?",
-      data_story = list(hook = "Users struggle", context = "")
+      data_story = new_data_story(
+        hook = "Users struggle",
+        context = "Dashboard complexity",
+        tension = "Users frustrated",
+        resolution = "Simplify design"
+      )
     )
 
     suggestions <- generate_stage_suggestions("Interpret", interpret_context)
@@ -728,3 +746,139 @@ test_that("functions are deterministic and consistent", {
     validate_required_params(problem = test_problem, evidence = "test")
   )
 })
+
+# ==============================================================================
+# VALIDATE_CHARACTER_PARAM_LEGACY ERROR BRANCH COVERAGE
+# ==============================================================================
+
+test_that("validate_character_param_legacy errors on NULL when not allowed", {
+  expect_error(
+    bidux:::validate_character_param_legacy(NULL, "my_param"),
+    "my_param.*cannot be NULL"
+  )
+})
+
+test_that("validate_character_param_legacy allows NULL when allow_null is TRUE", {
+  expect_silent(
+    bidux:::validate_character_param_legacy(NULL, "my_param", allow_null = TRUE)
+  )
+})
+
+test_that("validate_character_param_legacy errors on non-character input", {
+  expect_error(
+    bidux:::validate_character_param_legacy(123, "my_param"),
+    "my_param.*must be a single character string"
+  )
+})
+
+test_that("validate_character_param_legacy errors on vector of length > 1", {
+  expect_error(
+    bidux:::validate_character_param_legacy(c("a", "b"), "my_param"),
+    "my_param.*must be a single character string"
+  )
+})
+
+test_that("validate_character_param_legacy errors on empty/whitespace string", {
+  expect_error(
+    bidux:::validate_character_param_legacy("", "my_param"),
+    "my_param.*cannot be empty"
+  )
+  expect_error(
+    bidux:::validate_character_param_legacy("   ", "my_param"),
+    "my_param.*cannot be empty"
+  )
+})
+
+# ==============================================================================
+# VALIDATE_LIST_PARAM ERROR BRANCH COVERAGE
+# ==============================================================================
+
+test_that("validate_list_param errors on NULL when allow_null is FALSE", {
+  expect_error(
+    bidux:::validate_list_param(NULL, "my_list", allow_null = FALSE),
+    "my_list.*cannot be NULL"
+  )
+})
+
+test_that("validate_list_param errors on non-list input", {
+  expect_error(
+    bidux:::validate_list_param("not a list", "my_list"),
+    "my_list.*must be a list"
+  )
+  expect_error(
+    bidux:::validate_list_param(42, "my_list"),
+    "my_list.*must be a list"
+  )
+})
+
+test_that("validate_list_param errors when required names are missing", {
+  test_list <- list(a = 1, b = 2)
+  expect_error(
+    bidux:::validate_list_param(
+      test_list,
+      "my_list",
+      required_names = c("a", "c")
+    ),
+    "my_list.*missing required elements.*c"
+  )
+})
+
+# ==============================================================================
+# VALIDATE_PARAM EDGE CASES FOR COVERAGE
+# ==============================================================================
+
+test_that("validate_param detects wrong logical type", {
+  expect_error(
+    validate_param("true", "flag", "logical"),
+    "flag.*must be a.*logical"
+  )
+})
+
+test_that("validate_param enforces single logical with max_length = 1", {
+  # NA logical with max_length = 1 triggers special case
+  expect_error(
+    validate_param(NA, "flag", "logical", max_length = 1),
+    "flag"
+  )
+})
+
+# ==============================================================================
+# CLASSIFY_AUDIENCE BRANCH COVERAGE
+# ==============================================================================
+
+test_that("classify_audience returns all 5 categories", {
+  # executive
+
+  expect_equal(
+    bidux:::classify_audience("Executive leadership team"),
+    "executive"
+  )
+  expect_equal(bidux:::classify_audience("C-suite directors"), "executive")
+
+  # analyst
+  expect_equal(bidux:::classify_audience("Data scientist team"), "analyst")
+  expect_equal(bidux:::classify_audience("Statistician group"), "analyst")
+
+  # marketing
+  expect_equal(bidux:::classify_audience("Marketing department"), "marketing")
+  expect_equal(
+    bidux:::classify_audience("Sales and business development"),
+    "marketing"
+  )
+
+  # operations
+  expect_equal(bidux:::classify_audience("Operations team"), "operations")
+  expect_equal(
+    bidux:::classify_audience("Clinical frontline workers"),
+    "operations"
+  )
+
+  # general (fallback)
+  expect_equal(bidux:::classify_audience("General public"), "general")
+  expect_equal(bidux:::classify_audience("Random users"), "general")
+
+  # edge cases
+  expect_equal(bidux:::classify_audience(NULL), "general")
+  expect_equal(bidux:::classify_audience(""), "general")
+  expect_equal(bidux:::classify_audience("   "), "general")
+})
